@@ -418,7 +418,9 @@ TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str}, total=False)
 _RequiredWebhookFilterTypeDef = TypedDict(
     "_RequiredWebhookFilterTypeDef",
     {
-        "type": Literal["EVENT", "BASE_REF", "HEAD_REF", "ACTOR_ACCOUNT_ID", "FILE_PATH"],
+        "type": Literal[
+            "EVENT", "BASE_REF", "HEAD_REF", "ACTOR_ACCOUNT_ID", "FILE_PATH", "COMMIT_MESSAGE"
+        ],
         "pattern": str,
     },
 )
